package com.jiuqi.db;

import java.io.ByteArrayInputStream;
import java.io.InputStream;
import java.io.Reader;
import java.math.BigDecimal;
import java.net.URL;
import java.sql.Array;
import java.sql.Blob;
import java.sql.Clob;
import java.sql.Connection;
import java.sql.Date;
import java.sql.ParameterMetaData;
import java.sql.PreparedStatement;
import java.sql.Ref;
import java.sql.ResultSet;
import java.sql.ResultSetMetaData;
import java.sql.SQLException;
import java.sql.SQLWarning;
import java.sql.Time;
import java.sql.Timestamp;
import java.util.Calendar;

/* loaded from: com_jiuqi_db.jar:com/jiuqi/db/DBPreparedStatement.class */
public class DBPreparedStatement implements PreparedStatement {
    private PreparedStatement stmt;
    private Connection conn;

    public DBPreparedStatement(PreparedStatement aStmt, Connection aConn) {
        this.stmt = aStmt;
        this.conn = aConn;
        DBTrace.createConnection(this);
    }

    @Override // java.sql.Statement
    public ResultSet executeQuery(String string) throws SQLException {
        ResultSet rs = this.stmt.executeQuery(string);
        return new DBResultSet(this, rs);
    }

    @Override // java.sql.Statement
    public int executeUpdate(String string) throws SQLException {
        return this.stmt.executeUpdate(string);
    }

    @Override // java.sql.Statement, java.lang.AutoCloseable
    public void close() throws SQLException {
        this.stmt.close();
        DBTrace.closeConnection(this);
    }

    @Override // java.sql.Statement
    public int getMaxFieldSize() throws SQLException {
        return this.stmt.getMaxFieldSize();
    }

    @Override // java.sql.Statement
    public void setMaxFieldSize(int int0) throws SQLException {
        this.stmt.setMaxFieldSize(int0);
    }

    @Override // java.sql.Statement
    public int getMaxRows() throws SQLException {
        return this.stmt.getMaxRows();
    }

    @Override // java.sql.Statement
    public void setMaxRows(int int0) throws SQLException {
        this.stmt.setMaxRows(int0);
    }

    @Override // java.sql.Statement
    public void setEscapeProcessing(boolean boolean0) throws SQLException {
        this.stmt.setEscapeProcessing(boolean0);
    }

    @Override // java.sql.Statement
    public int getQueryTimeout() throws SQLException {
        return this.stmt.getQueryTimeout();
    }

    @Override // java.sql.Statement
    public void setQueryTimeout(int int0) throws SQLException {
        this.stmt.setQueryTimeout(int0);
    }

    @Override // java.sql.Statement
    public void cancel() throws SQLException {
        this.stmt.cancel();
    }

    @Override // java.sql.Statement
    public SQLWarning getWarnings() throws SQLException {
        return this.stmt.getWarnings();
    }

    @Override // java.sql.Statement
    public void clearWarnings() throws SQLException {
        this.stmt.clearWarnings();
    }

    @Override // java.sql.Statement
    public void setCursorName(String string) throws SQLException {
        this.stmt.setCursorName(string);
    }

    @Override // java.sql.Statement
    public boolean execute(String string) throws SQLException {
        return this.stmt.execute(string);
    }

    @Override // java.sql.Statement
    public ResultSet getResultSet() throws SQLException {
        return this.stmt.getResultSet();
    }

    @Override // java.sql.Statement
    public int getUpdateCount() throws SQLException {
        return this.stmt.getUpdateCount();
    }

    @Override // java.sql.Statement
    public boolean getMoreResults() throws SQLException {
        return this.stmt.getMoreResults();
    }

    @Override // java.sql.Statement
    public void setFetchDirection(int int0) throws SQLException {
        this.stmt.setFetchDirection(int0);
    }

    @Override // java.sql.Statement
    public int getFetchDirection() throws SQLException {
        return this.stmt.getFetchDirection();
    }

    @Override // java.sql.Statement
    public void setFetchSize(int int0) throws SQLException {
        this.stmt.setFetchSize(int0);
    }

    @Override // java.sql.Statement
    public int getFetchSize() throws SQLException {
        return this.stmt.getFetchSize();
    }

    @Override // java.sql.Statement
    public int getResultSetConcurrency() throws SQLException {
        return this.stmt.getResultSetConcurrency();
    }

    @Override // java.sql.Statement
    public int getResultSetType() throws SQLException {
        return this.stmt.getResultSetType();
    }

    @Override // java.sql.Statement
    public void addBatch(String string) throws SQLException {
        this.stmt.addBatch(string);
    }

    @Override // java.sql.Statement
    public void clearBatch() throws SQLException {
        this.stmt.clearBatch();
    }

    @Override // java.sql.Statement
    public int[] executeBatch() throws SQLException {
        return this.stmt.executeBatch();
    }

    @Override // java.sql.Statement
    public Connection getConnection() throws SQLException {
        return this.conn;
    }

    @Override // java.sql.PreparedStatement
    public ResultSet executeQuery() throws SQLException {
        ResultSet rs = this.stmt.executeQuery();
        return new DBResultSet(this, rs);
    }

    @Override // java.sql.PreparedStatement
    public int executeUpdate() throws SQLException {
        return this.stmt.executeUpdate();
    }

    @Override // java.sql.PreparedStatement
    public void setNull(int int0, int int1) throws SQLException {
        this.stmt.setNull(int0, int1);
    }

    @Override // java.sql.PreparedStatement
    public void setBoolean(int int0, boolean boolean1) throws SQLException {
        this.stmt.setBoolean(int0, boolean1);
    }

    @Override // java.sql.PreparedStatement
    public void setByte(int int0, byte byte1) throws SQLException {
        this.stmt.setByte(int0, byte1);
    }

    @Override // java.sql.PreparedStatement
    public void setShort(int int0, short short1) throws SQLException {
        this.stmt.setShort(int0, short1);
    }

    @Override // java.sql.PreparedStatement
    public void setInt(int int0, int int1) throws SQLException {
        this.stmt.setInt(int0, int1);
    }

    @Override // java.sql.PreparedStatement
    public void setLong(int int0, long long1) throws SQLException {
        this.stmt.setLong(int0, long1);
    }

    @Override // java.sql.PreparedStatement
    public void setFloat(int int0, float float1) throws SQLException {
        this.stmt.setFloat(int0, float1);
    }

    @Override // java.sql.PreparedStatement
    public void setDouble(int int0, double double1) throws SQLException {
        this.stmt.setDouble(int0, double1);
    }

    @Override // java.sql.PreparedStatement
    public void setBigDecimal(int int0, BigDecimal bigDecimal) throws SQLException {
        this.stmt.setBigDecimal(int0, bigDecimal);
    }

    @Override // java.sql.PreparedStatement
    public void setString(int int0, String string) throws SQLException {
        this.stmt.setString(int0, string);
    }

    @Override // java.sql.PreparedStatement
    public void setBytes(int int0, byte[] byteArray) throws SQLException {
        byte[] bytes = byteArray == null ? new byte[0] : byteArray;
        try {
            InputStream stream = new ByteArrayInputStream(bytes);
            try {
                this.stmt.setBinaryStream(int0, stream, stream.available());
                stream.close();
            } catch (Throwable th) {
                stream.close();
                throw th;
            }
        } catch (Exception ex) {
            throw new SQLException("写入流失败" + ex.getMessage());
        }
    }

    @Override // java.sql.PreparedStatement
    public void setDate(int int0, Date date) throws SQLException {
        this.stmt.setDate(int0, date);
    }

    @Override // java.sql.PreparedStatement
    public void setTime(int int0, Time time) throws SQLException {
        this.stmt.setTime(int0, time);
    }

    @Override // java.sql.PreparedStatement
    public void setTimestamp(int int0, Timestamp timestamp) throws SQLException {
        this.stmt.setTimestamp(int0, timestamp);
    }

    @Override // java.sql.PreparedStatement
    public void setAsciiStream(int int0, InputStream inputStream, int int2) throws SQLException {
        this.stmt.setAsciiStream(int0, inputStream, int2);
    }

    @Override // java.sql.PreparedStatement
    public void setUnicodeStream(int int0, InputStream inputStream, int int2) throws SQLException {
        this.stmt.setUnicodeStream(int0, inputStream, int2);
    }

    @Override // java.sql.PreparedStatement
    public void setBinaryStream(int int0, InputStream inputStream, int int2) throws SQLException {
        this.stmt.setBinaryStream(int0, inputStream, int2);
    }

    @Override // java.sql.PreparedStatement
    public void clearParameters() throws SQLException {
        this.stmt.clearParameters();
    }

    @Override // java.sql.PreparedStatement
    public void setObject(int int0, Object object, int int2, int int3) throws SQLException {
        this.stmt.setObject(int0, object, int2, int3);
    }

    @Override // java.sql.PreparedStatement
    public void setObject(int int0, Object object, int int2) throws SQLException {
        this.stmt.setObject(int0, object, int2);
    }

    @Override // java.sql.PreparedStatement
    public void setObject(int int0, Object object) throws SQLException {
        if (object != null && (object instanceof byte[])) {
            setBytes(int0, (byte[]) object);
        } else {
            this.stmt.setObject(int0, object);
        }
    }

    @Override // java.sql.PreparedStatement
    public boolean execute() throws SQLException {
        return this.stmt.execute();
    }

    @Override // java.sql.PreparedStatement
    public void addBatch() throws SQLException {
        this.stmt.addBatch();
    }

    @Override // java.sql.PreparedStatement
    public void setCharacterStream(int int0, Reader reader, int int2) throws SQLException {
        this.stmt.setCharacterStream(int0, reader, int2);
    }

    @Override // java.sql.PreparedStatement
    public void setRef(int int0, Ref ref) throws SQLException {
        this.stmt.setRef(int0, ref);
    }

    @Override // java.sql.PreparedStatement
    public void setBlob(int int0, Blob blob) throws SQLException {
        this.stmt.setBlob(int0, blob);
    }

    @Override // java.sql.PreparedStatement
    public void setClob(int int0, Clob clob) throws SQLException {
        this.stmt.setClob(int0, clob);
    }

    @Override // java.sql.PreparedStatement
    public void setArray(int int0, Array array) throws SQLException {
        this.stmt.setArray(int0, array);
    }

    @Override // java.sql.PreparedStatement
    public ResultSetMetaData getMetaData() throws SQLException {
        return this.stmt.getMetaData();
    }

    @Override // java.sql.PreparedStatement
    public void setDate(int int0, Date date, Calendar calendar) throws SQLException {
        this.stmt.setDate(int0, date, calendar);
    }

    @Override // java.sql.PreparedStatement
    public void setTime(int int0, Time time, Calendar calendar) throws SQLException {
        this.stmt.setTime(int0, time, calendar);
    }

    @Override // java.sql.PreparedStatement
    public void setTimestamp(int int0, Timestamp timestamp, Calendar calendar) throws SQLException {
        this.stmt.setTimestamp(int0, timestamp, calendar);
    }

    @Override // java.sql.PreparedStatement
    public void setNull(int int0, int int1, String string) throws SQLException {
        this.stmt.setNull(int0, int1, string);
    }

    @Override // java.sql.PreparedStatement
    public void setURL(int parameterIndex, URL x) throws SQLException {
        this.stmt.setURL(parameterIndex, x);
    }

    @Override // java.sql.Statement
    public boolean getMoreResults(int int0) throws SQLException {
        return this.stmt.getMoreResults(int0);
    }

    @Override // java.sql.Statement
    public ResultSet getGeneratedKeys() throws SQLException {
        return this.stmt.getGeneratedKeys();
    }

    @Override // java.sql.Statement
    public int executeUpdate(String sql, int autoGeneratedKeys) throws SQLException {
        return this.stmt.executeUpdate(sql, autoGeneratedKeys);
    }

    @Override // java.sql.Statement
    public int executeUpdate(String sql, int[] columnIndexes) throws SQLException {
        return this.stmt.executeUpdate(sql, columnIndexes);
    }

    @Override // java.sql.Statement
    public int executeUpdate(String sql, String[] columnNames) throws SQLException {
        return this.stmt.executeUpdate(sql, columnNames);
    }

    @Override // java.sql.Statement
    public boolean execute(String sql, int autoGeneratedKeys) throws SQLException {
        return this.stmt.execute(sql, autoGeneratedKeys);
    }

    @Override // java.sql.Statement
    public boolean execute(String sql, int[] columnIndexes) throws SQLException {
        return this.stmt.execute(sql, columnIndexes);
    }

    @Override // java.sql.Statement
    public boolean execute(String sql, String[] columnNames) throws SQLException {
        return this.stmt.execute(sql, columnNames);
    }

    @Override // java.sql.Statement
    public int getResultSetHoldability() throws SQLException {
        return this.stmt.getResultSetHoldability();
    }

    @Override // java.sql.PreparedStatement
    public ParameterMetaData getParameterMetaData() throws SQLException {
        return this.stmt.getParameterMetaData();
    }
}
